@@ -11,13 +11,14 @@ func (zig *Zig) Template() string {
 func (zig *Zig) Enabled() bool {
 	zig.extensions = []string{"*.zig", "*.zon"}
 	zig.projectFiles = []string{"build.zig"}
-	zig.commands = []*cmd{
-		{
+	zig.tooling = map[string]*cmd{
+		"zig": {
 			executable: "zig",
 			args:       []string{"version"},
 			regex:      `(?P<version>(?P<major>0|[1-9]\d*)\.(?P<minor>0|[1-9]\d*)\.(?P<patch>0|[1-9]\d*)(?:-(?P<prerelease>(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\.(?:0|[1-9]\d*|\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\+(?P<buildmetadata>[0-9a-zA-Z-]+(?:\.[0-9a-zA-Z-]+)*))?)`, //nolint:lll
 		},
 	}
+	zig.defaultTooling = []string{"zig"}
 
 	zig.versionURLTemplate = "https://ziglang.org/download/{{ .Major }}.{{ .Minor }}.{{ .Patch }}/release-notes.html"
 
